<?php

namespace App\Http\Controllers\Admin;

use App\Repositories\Classes\CategoryRepository;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use App\Http\Controllers\Controller; // Import the base Controller class
use App\Models\Category;
use App\Http\Requests\EditCategoryRequest;
class CategoryController extends Controller
{

    private $categoryRepo;
    public function __construct(CategoryRepository $categoryRepo){
        $this->categoryRepo = $categoryRepo;
    }
    public function all(Request $request){
        $business = $request->business;
        $categories = $this->categoryRepo->getAllCategories($business->id, $request);
        
        return response()->json([
            "categories" => $categories
            ]);
    }

    public function list(Request $request){
        $business = $request->business;
        $categories = $this->categoryRepo->getAllCategoriesList($business->id);
        
        return response()->json([
            "categories" => $categories
            ]);
    }


    public function oneCategory($id, Request $request){
        $business = $request->business;
        $category = $this->categoryRepo->getOneCategory($id, $business->id);

        return response()->json([
            "category" => $category
            ]);
    }

    public function add(Request $request){
        if($request->operation == 'edit' && (!$request->id || $request->id = '')){
            return response()->json([
                "message" => "NO"
            ]);
        }
        $data = $request->only(Category::FILLABLE);
        $data['code'] = "sl*hg$";
        $admin = auth()->guard('admin')->user();
        $data['added_by'] = $admin->id;
        if($request->image)
        $data['img'] = $request->image->store('web/images', 'public');
        $data['business_id'] = $request->business->id;
        $category = $this->categoryRepo->addCategory($request->business->id, $data);
        return response()->json([
            "category" => $category,
            "success" => true
        ]);
    //    dd($request);
    }

    public function edit(EditCategoryRequest $request){

        $data = $request->only(Category::FILLABLE);
        if($request->image)
        $data['img'] = $request->image->store('web/images', 'public');
        $data['business_id'] = $request->business->id;
        $category = $this->categoryRepo->editCategory($data);
        return response()->json([
            "category" => $category,
            "success" => true
        ]);
    }


    public function delete(Request $request){
        $category = $this->categoryRepo->deleteCategories(json_decode($request->ids));
        return response()->json([
            "category" => $category,    
            "success" => true
        ]);
    }

    public function active(Request $request){
        $category = $this->categoryRepo->activeCategories(json_decode($request->ids));
        return response()->json([
            "category" => $category,    
            "success" => true
        ]);
    }

    public function unactive(Request $request){
        $category = $this->categoryRepo->unactiveCategories(json_decode($request->ids));
        return response()->json([
            "category" => $category,    
            "success" => true
        ]);
    }
    
}
