<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Product extends Model
{
    use HasFactory, SoftDeletes;
    
     const FILLABLE = [
        "id",
        "code",
        "img",
        "name",
        "rate",
        "price",
        "baladi",
        "shami",
        "status",
        "big",
        "medium",
        "small",
        "sort",
        "added_by",
        "added_date",
        "category_id",
        "subcategory_id",
        "deleted_at",
        "created_at",
        "updated_at",
        "business_id"
        ];
        

        protected $fillable = self::FILLABLE;
        
        public function category(){
            return $this->belongsTo(Category::class, 'category_id', 'id');
        }

        public function subcategory(){
            return $this->belongsTo(Subcategory::class, 'subcategory_id', 'id');
        }

        public function admin(){
            return $this->belongsTo(Admin::class, 'added_by' ,'id');
        }
        
        public function scopeBusiness($q, $token){
            return $q->where("business_id", $token);
        }

        public function scopeSearch($query, $searchName = null, $searchCategory = null, $searchStatus = null, $searchAdmin = null, $searFromDate = null, $searToDate = null)
        {
            if (!empty($searchName)) {
                $query->where('name', 'LIKE', '%' . $searchName . '%');
            }
    
            if (!empty($searchCategory)) {
                $query->where('category_id', $searchCategory);
            }

            if ($searchStatus == '0' || $searchStatus == '1') {
                $query->where('status', $searchStatus);
            }

            if (!empty($searchAdmin)) {
                $query->where('added_by', $searchAdmin);
            }

            if (!empty($searFromDate)) {
                $query->where('added_date', '>=', $searFromDate);
            }

            if (!empty($searToDate)) {
                $query->where('added_date', '<=', $searToDate);
            }
    
            return $query;
        }
}
