<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Subcategory extends Model
{
    use HasFactory, SoftDeletes;
    
    const FILLABLE = [
        "id",
        "code",
        "name",
        "sort",
        "status",
        "rate",
        "category_id",
        "deleted_at",
        "created_at",
        "updated_at",
        "business_id"
        ];
     protected $fillable = self::FILLABLE;
        
        
        public function category(){
        return $this->belongsTo(Category::class, 'category_id', 'id');
        }
         
        public function admin(){
            return $this->belongsTo(Admin::class, 'added_by' ,'id');
        }

        public function products(){
        return $this->hasMany(Product::class, 'subcategory_id', 'id');
        }
        
        
        public function business(){
            return $this->belongsTo(Business::class, 'business_id', 'id');
        }
            
        public function scopeBusiness($q, $token){
            return $q->where("business_id", $token);
        }

        public function scopeSearch($query, $searchName = null, $searchCategory = null, $searchStatus = null, $searchAdmin = null, $searFromDate = null, $searToDate = null)
        {
            if (!empty($searchName)) {
                $query->where('name', 'LIKE', '%' . $searchName . '%');
            }
    
            if (!empty($searchCategory)) {
                $query->where('category_id', $searchCategory);
            }

            if ($searchStatus == '0' || $searchStatus == '1') {
                $query->where('status', $searchStatus);
            }

            if (!empty($searchAdmin)) {
                $query->where('added_by', $searchAdmin);
            }

            if (!empty($searFromDate)) {
                $query->where('added_date', '>=', $searFromDate);
            }

            if (!empty($searToDate)) {
                $query->where('added_date', '<=', $searToDate);
            }
    
            return $query;
        }
}
