<?php
namespace App\Repositories\Classes;

use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;
use App\Models\Category;

class CategoryRepository{
    
    public function getAllCategories($id, $data){

        try{
            $name = $data->name ??null;
            $category = $data->category ??null;
            $admin = $data->admin ??null;
            $status = $data->status == '0' || $data->status == '1' ?$data->status:null;
            $from = $data->from ??null;
            $to = $data->to ??null;
            if($from){
                $dtf = Carbon::parse($from);
                $from = $dtf->format('Y-m-d H:i:s');
            }

            if($to){
                $dtf = Carbon::parse($to);
                $to = $dtf->format('Y-m-d H:i:s');
            }
            $categories = category::query()
            ->business($id)
            ->search($name, $status, $admin, $from, $to)
            ->with([
                'admin:id,name',   // Use shorthand syntax for selecting columns
            ])
            ->paginate(20, ['*'], 'page', $data->page);
    
            $categories->each(function ($category) {
                $category->added_by_name = $category->admin->name; // Collect admin names
                unset($category->admin); // Optionally remove the employees attribute
            });
    
            return $categories;
        }catch (\Exception $e) {
            return response()->json([
                'error' => 'An error occurred while fetching the categories.',
                'message' => $e->getMessage()
            ], 500);
        }
        
    }

    public function getAllCategoriesList($id){
        $categories = category::query()
        ->business($id)
        ->select( 'id','name')->get();

        return $categories;
    }
    public function getOneCategory($id, $businessId){
        $category = Category::business($businessId)->find($id);
        return $category;
    }
    public function addCategory($businessId, $data){
        // $data->all()['business_id'] = $businessId;
        $category = Category::create($data);
        return $category;
    }
    
    public function editCategory($data){
        DB::beginTransaction();

        try {
            $category = Category::where('business_id', $data['business_id'])
                                 ->where('id', $data['id'])
                                 ->firstOrFail();
    
            $oldImage = $category->img;
    
            $category->update($data);
    
            if (isset($data['img']) && $oldImage) {
                Storage::disk('public')->delete($oldImage);
            }
    
            DB::commit();
        } catch (\Exception $e) {
            DB::rollBack();
            throw $e;
        }
    
        return $category;
    }
    public function deleteCategories($ids){
        return Category::whereIn('id', $ids)->delete();
        
    }

    public function activeCategories($ids){
        return Category::whereIn('id', $ids)->update(["status" => 1]);
        
    }
    
    public function unactiveCategories($ids){
        return Category::whereIn('id', $ids)->update(["status" => 0]);
        
    }
}