<?php
namespace App\Repositories\Classes;

use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;
use App\Models\Product;
use Carbon\Carbon;
class productRepository{
    
    public function getAllProducts($id, $data){
        try {
            $name = $data->name ??null;
            $category = $data->category ??null;
            $admin = $data->admin ??null;
            $status = $data->status == '0' || $data->status == '1' ?$data->status:null;
            $from = $data->from ??null;
            $to = $data->to ??null;
            if($from){
                $dtf = Carbon::parse($from);
                $from = $dtf->format('Y-m-d H:i:s');
            }

            if($to){
                $dtf = Carbon::parse($to);
                $to = $dtf->format('Y-m-d H:i:s');
            }
            $products = Product::query()
                ->business($id)
                ->search($name, $category, $status, $admin, $from, $to)
                ->with([
                    'admin:id,name',   // Use shorthand syntax for selecting columns
                    'category:id,name', // Use shorthand syntax for selecting columns
                    'subcategory:id,name' // Use shorthand syntax for selecting columns
                ])
                ->paginate(20, ['*'], 'page', +$data->page);
        
            $products->each(function ($product) {
                $product->added_by_name = $product->admin->name; // Collect admin names
                $product->category_name = $product->category->name; // Collect category names
                $product->subcategory_name = $product->subcategory->name; // Collect category names
                
                unset($product->admin, $product->category, $product->subcategory); // Remove the unnecessary attributes
            });
        
            return response()->json([
                "products" => $products
            ]);
        
        } catch (\Exception $e) {
            return response()->json([
                'error' => 'An error occurred while fetching the products.',
                'message' => $e->getMessage()
            ], 500);
        }
        

    }


    public function getAllProductsSearch($id, $search_name = null, $search_category = null)
    {
        try {
            $products = Product::query()
                ->business($id) // Assuming this is a custom scope or method
                ->search($search_name, $search_category) // Apply the search scope
                ->with([
                    'admin:id,name',   // Use shorthand syntax for selecting columns
                    'category:id,name' // Use shorthand syntax for selecting columns
                ])
                ->paginate(20); // Paginate without specifying the page parameter if it's not used
            
            $products->each(function ($product) {
                $product->added_by_name = $product->admin->name; // Collect admin names
                $product->category_name = $product->category->name; // Collect category names
                
                unset($product->admin, $product->category); // Remove the unnecessary attributes
            });
    
            return response()->json([
                "products" => $products
            ]);
    
        } catch (\Exception $e) {
            return response()->json([
                'error' => 'An error occurred while fetching the products.',
                'message' => $e->getMessage()
            ], 500);
        }
    }
    
    public function getOneProduct($id, $businessId){
        $product = product::query()->business($businessId)->find($id);
        return $product;
    }
    public function addProduct($businessId, $data){
        // $data->all()['business_id'] = $businessId;
        $product = Product::create($data);
        return $product;
    }
    
    public function editProduct($data){
        DB::beginTransaction();

        try {
            $product = Product::where('business_id', $data['business_id'])
                                 ->where('id', $data['id'])
                                 ->firstOrFail();
    
            $oldImage = $product->img;
    
            $product->update($data);
    
            if (isset($data['img']) && $oldImage) {
                Storage::disk('public')->delete($oldImage);
            }
    
            DB::commit();
            return $product;
        } catch (\Exception $e) {
            DB::rollBack();
            throw $e;
        }
    
    }
    public function deleteProducts($ids){
        return Product::whereIn('id', $ids)->delete();
        
    }

    public function activeProducts($ids){
        return Product::whereIn('id', $ids)->update(["status" => 1]);
        
    }
    
    public function unactiveProducts($ids){
        return Product::whereIn('id', $ids)->update(["status" => 0]);
        
    }
}