<?php
namespace App\Repositories\Classes;

use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;
use App\Models\Subcategory;
use Carbon\Carbon;
class SubcategoryRepository{
    
    public function getAllSubcategories($id, $data){
        try {
            $name = $data->name ??null;
            $category = $data->category ??null;
            $admin = $data->admin ??null;
            $status = $data->status == '0' || $data->status == '1' ?$data->status:null;
            $from = $data->from ??null;
            $to = $data->to ??null;
            if($from){
                $dtf = Carbon::parse($from);
                $from = $dtf->format('Y-m-d H:i:s');
            }

            if($to){
                $dtf = Carbon::parse($to);
                $to = $dtf->format('Y-m-d H:i:s');
            }
            $subcategories = Subcategory::query()
                ->business($id)
                ->search($name, $category, $status, $admin, $from, $to)
                ->with([
                    'admin:id,name',   // Use shorthand syntax for selecting columns
                    'category:id,name' // Use shorthand syntax for selecting columns
                ])
                ->paginate(20, ['*'], 'page', +$data->page);
        
            $subcategories->each(function ($subcategory) {
                $subcategory->added_by_name = $subcategory->admin->name; // Collect admin names
                $subcategory->category_name = $subcategory->category->name; // Collect category names
                
                unset($subcategory->admin, $subcategory->category); // Remove the unnecessary attributes
            });
        
            return response()->json([
                "subcategories" => $subcategories
            ]);
        
        } catch (\Exception $e) {
            return response()->json([
                'error' => 'An error occurred while fetching the subcategories.',
                'message' => $e->getMessage()
            ], 500);
        }
        

    }


    public function getAllSubcategoriesSearch($id, $search_name = null, $search_category = null)
    {
        try {
            $subcategories = Subcategory::query()
                ->business($id) // Assuming this is a custom scope or method
                ->search($search_name, $search_category) // Apply the search scope
                ->with([
                    'admin:id,name',   // Use shorthand syntax for selecting columns
                    'category:id,name' // Use shorthand syntax for selecting columns
                ])
                ->paginate(20); // Paginate without specifying the page parameter if it's not used
            
            $subcategories->each(function ($subcategory) {
                $subcategory->added_by_name = $subcategory->admin->name; // Collect admin names
                $subcategory->category_name = $subcategory->category->name; // Collect category names
                
                unset($subcategory->admin, $subcategory->category); // Remove the unnecessary attributes
            });
    
            return response()->json([
                "subcategories" => $subcategories
            ]);
    
        } catch (\Exception $e) {
            return response()->json([
                'error' => 'An error occurred while fetching the subcategories.',
                'message' => $e->getMessage()
            ], 500);
        }
    }
    
    public function getOneSubcategory($id, $businessId){
        $subcategory = Subcategory::query()->business($businessId)->find($id);
        return $subcategory;
    }
    public function addSubcategory($businessId, $data){
        // $data->all()['business_id'] = $businessId;
        $subcategory = Subcategory::create($data);
        return $subcategory;
    }
    
    public function editSubcategory($data){
        DB::beginTransaction();

        try {
            $subcategory = Subcategory::where('business_id', $data['business_id'])
                                 ->where('id', $data['id'])
                                 ->firstOrFail();
    
            // $oldImage = $subcategory->img;
    
            $subcategory->update($data);
    
            // if (isset($data['img']) && $oldImage) {
            //     Storage::disk('public')->delete($oldImage);
            // }
    
            DB::commit();
            return $subcategory;
        } catch (\Exception $e) {
            DB::rollBack();
            throw $e;
        }
    
    }
    public function deleteSubcategories($ids){
        return Subcategory::whereIn('id', $ids)->delete();
        
    }

    public function activeSubcategories($ids){
        return Subcategory::whereIn('id', $ids)->update(["status" => 1]);
        
    }
    
    public function unactiveSubcategories($ids){
        return Subcategory::whereIn('id', $ids)->update(["status" => 0]);
        
    }

    public function getsubcategoriesListByCategoryId($category_id){
        $subcategories = Subcategory::where('category_id', $category_id)->get();
        return $subcategories;
    }
}